@@ -2,7 +2,11 @@
 
 set -eo pipefail
 
-LLVM_DIR=$(find /usr -name AddLLVM.cmake -printf '%h\n' -quit)
+if [[ "$(uname)" = "Darwin" ]]; then
+  LLVM_DIR=$(find /usr/local/Cellar/llvm -name AddLLVM.cmake -print0 -quit | xargs -0 dirname)
+else
+  LLVM_DIR=$(find /usr -name AddLLVM.cmake -printf '%h\n' -quit)
+fi
 [[ -d "${LLVM_DIR}" ]] || { >&2 echo "Couldn't infer LLVM_DIR"; exit 1; }
 export LLVM_DIR
 
